#
# spec file for package perl-MIME-Lite
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name MIME-Lite
Name:           perl-MIME-Lite
Version:        3.033
Release:        1.15
Summary:        Low-calorie MIME generator
License:        Artistic-1.0 OR GPL-1.0-or-later
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/R/RJ/RJBS/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Email::Date::Format) >= 1.000
BuildRequires:  perl(MIME::Types) >= 1.28
BuildRequires:  perl(Mail::Address) >= 1.62
Requires:       perl(Email::Date::Format) >= 1.000
Requires:       perl(MIME::Types) >= 1.28
Requires:       perl(Mail::Address) >= 1.62
%{perl_requires}

%description
In the never-ending quest for great taste with fewer calories, we proudly
present: _MIME::Lite_.

MIME::Lite is intended as a simple, standalone module for generating (not
parsing!) MIME messages... specifically, it allows you to output a simple,
decent single- or multi-part message with text or binary attachments. It
does not require that you have the Mail:: or MIME:: modules installed, but
will work with them if they are.

You can specify each message part as either the literal data itself (in a
scalar or array), or as a string which can be given to open() to get a
readable filehandle (e.g., "<filename" or "somecommand|").

You don't need to worry about encoding your message data: this module will
do that for you. It handles the 5 standard MIME encodings.

%prep
%autosetup  -n %{cpan_name}-%{version}
find . -type f ! -path "*/t/*" ! -name "*.pl" ! -path "*/bin/*" ! -path "*/script/*" ! -name "configure" -print0 | xargs -0 chmod 644

%build
perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc examples README
%license COPYING LICENSE

%changelog
* Sun Jun 13 2021 Tina Müller <timueller+perl@suse.de>
- updated to 3.033
  see /usr/share/doc/packages/perl-MIME-Lite/changes.pod
  =item Version 3.033
  No changes since previous version, just made non-trial.
  =item Version 3.032
  Fix an error in printing to Net::SMTP (thanks, Peter Heirich)
  Add "use warnings" and require v5.6
* Mon Oct 28 2019 <timueller+perl@suse.de>
- updated to 3.031
  see /usr/share/doc/packages/perl-MIME-Lite/changes.pod
  =item Version 3.031
  Add an SSL option to connect to the SMTP relay via SSL on port 465. (thanks,
  Max Maischein)
  Document some tips on using non-ASCII content with MIME::Lite (thanks,
  traveljury.com and Tom Hukins)
* Mon Nov 25 2013 coolo@suse.com
- updated to 3.030
  Make send_by_sendmail set sender like documentation says it does (thanks,
  Michael Schout!)
* Wed Jun  5 2013 coolo@suse.com
- updated to 3.029
  Allow the MIME-Version header to be replaced (thanks, Florian!)
* Tue Dec  6 2011 coolo@suse.com
- shorten license string
* Fri Nov 18 2011 coolo@suse.com
- use original .tar.gz
* Wed Nov  9 2011 pascal.bleser@opensuse.org
- update to 3.028: documentation fixes
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Mon Nov 29 2010 coolo@novell.com
- remove /var/adm/perl-modules
* Wed Jan 13 2010 anicka@suse.cz
- update to 3.027
  * Add send_to_testfile method
  * Fix tests to pass with MIME::Types 1.28
  * Added back support for providing a non-default SMTP port
* Sun Jan 10 2010 jengelh@medozas.de
- enable parallel build
* Fri Feb 27 2009 anicka@suse.cz
- update to 3.024
  * Respect crazy people who put multiple Cc or Bcc headers in message
  * Cope with missing local sendmail
  * fixes
- require perl-Email-Date-Format, perl-MailTools, perl-MIME-Types
* Sat Mar 15 2008 coolo@suse.de
- removing executable bits on documentation
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Sep 28 2005 dmueller@suse.de
- add norootforbuild
* Fri Aug 22 2003 mjancar@suse.cz
- require the perl version we build with
* Mon Jul 14 2003 freitag@suse.de
- removed useless comments and fixed the docs
* Mon Jul 14 2003 freitag@suse.de
- changed to vendor directories, used autobuild macros
* Wed Jun 18 2003 coolo@suse.de
- package directories
* Sun May 25 2003 ro@suse.de
- remove unpackaged files from buildroot
* Mon May 19 2003 freitag@suse.de
- update to version 3.01, only small maintenance, no new feature.
  removed perllocal.pod off the filesystem
* Thu Aug  8 2002 mls@suse.de
- use sitearch macro
* Tue Jul 30 2002 freitag@suse.de
- update to version 2.117 with feature improvements.
* Tue Jul  2 2002 mls@suse.de
- remove race in .packlist generation
* Fri Jun  8 2001 freitag@suse.de
- new package with initial version 2.111, required by pdb
